## candid-python: A [Candid Health](https://joincandidhealth.com) Python client
[![PyPI](https://img.shields.io/pypi/v/candidhealth)](https://pypi.org/project/candidhealth/)

### Installation
```bash
pip install candidhealth   # or poetry install, etc.
```
